/*  $Id: VerbisteCApi.h,v 1.1 2003/10/14 21:50:46 sarrazip Exp $
    FrenchVerbDictionary.h - Dictionary of verbs and conjugation templates

    verbiste - French conjugation system
    Copyright (C) 2003 Pierre Sarrazin <http://sarrazip.com/>

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
    02111-1307, USA.
*/

#ifndef _H_VerbisteCAPI
#define _H_VerbisteCAPI

#include <stddef.h>


#ifdef __cplusplus
  extern "C" {
#endif


int verbiste_init( void );

int verbiste_close( void );

typedef enum 
{
    INVALID_MODE, INFINITIVE_MODE, INDICATIVE_MODE, CONDITIONAL_MODE,
    SUBJUNCTIVE_MODE, IMPERATIVE_MODE, PARTICIPLE_MODE
} Verbiste_Mode;


typedef enum 
{
    INVALID_TENSE, PRESENT_TENSE, PAST_TENSE, IMPERFECT_TENSE, FUTURE_TENSE
} Verbiste_Tense;

typedef enum 
{
  INVALID_PERSON=0, FIRST =1, SECOND=2, THIRD=3
} Verbiste_Person;


typedef enum 
{
  SINGULAR=0, PLURAL=1
} Verbiste_Number;

#define MAX_CHAR_BUFFER 64

typedef char char_buffer[MAX_CHAR_BUFFER];

typedef struct 
{
  char_buffer      infinitive_verb;
  Verbiste_Mode    m;
  Verbiste_Tense   t;
  Verbiste_Person  p;
  Verbiste_Number  n;
} Verbiste_verbMTPN;


/**
    Returns the English name (in ASCII) of the given mode.
*/
/**
Returns the English name (in ASCII) of the given tense.
*/

const char *verbiste_getModeName(Verbiste_Mode m);
const char *verbiste_getTenseName(Verbiste_Tense t);
const char *verbiste_getPersonName(Verbiste_Person p);
const char *verbiste_getNumberName(Verbiste_Number n);



int verbiste_deconjugate( const char* verb_latin1, 
			  Verbiste_verbMTPN *out_vector,
			  size_t buffer_size_char, 
			  size_t *nb_rec_found,
			  size_t *nb_rec_written);

#ifdef __cplusplus
}
#endif

#endif
